<?php
/* setup dependencies */
$pluginDir = (function_exists('plugin_dir_path'))? plugin_dir_path( __FILE__ ) : __DIR__ . '/';  
define( "PLUGIN_PATH", $pluginDir ); 

require_once PLUGIN_PATH . 'bp-generator.class.php';
require_once PLUGIN_PATH . 'ajax.php';

/*
	BPReviewGenerator class
	
	setup the plugin to go through setup, activation,
	and deactivation steps
*/


class BPFancyReviewGenerator
{	
	/* store the plugin name */
	public static $pluginName = "BP Fancy Reviews";
	
	/* store the version number */
	public $version = '0.5.1';
	
	public function __construct() 
	{ 
		
	}
	
	/* setup everything when the object is created */
	public function setup()
	{
		/* setup all the actions */
		$this->addActions();
	}
	
	/* load all public scripts and styles */ 
	public function loadPublicScripts() 
	{
		global $version;
		
		wp_enqueue_style( 'bp-reviews-style', plugins_url( '../../css/reviews-style.css', __FILE__ ) );
		wp_enqueue_style( 'bp-animation', plugins_url( '../../css/animation.css', __FILE__ ) );
		
		wp_enqueue_script( 'bp-reviews-main', plugins_url('../js/reviews-java.js', __FILE__ ), array( 'jquery' ), $version, true );
	} 
	
	/* load all admin scripts and styles */ 
	public function loadAdminScripts() 
	{
		global $version;
		
		wp_enqueue_style( 'bp-reviews-style', plugins_url( '../../css/reviews-style.css', __FILE__ ) );
		wp_enqueue_style( 'bp-animation', plugins_url( '../../css/animation.css', __FILE__ ) );
		wp_enqueue_style( 'bootstrap-4', plugins_url( '../../bootstrap-4/css/bootstrap.min.css', __FILE__ ), array(), null );
		
		wp_enqueue_script( 'tether', plugins_url( '../js/tether.min.js', __FILE__ ), array( 'jquery'), null, true );
		wp_enqueue_script( 'bootstrap', plugins_url( '../../bootstrap-4/js/bootstrap.min.js', __FILE__ ), array( 'jquery', 'tether' ), null, true );
	}
	
	/* this will add the pages to the menu */ 
	public function addMenuPages() 
	{ 
		$icon_url = PLUGIN_PATH . '../../images/five-star.png';
		
		
		add_menu_page( 'BPI Fancy Reviews', 'BPI Fancy Reviews', 'manage_options', 'reviews-overview', array( &$this, 'overviewPageLayout' ), $icon_url, null ); 
		
		/*  this is just a brief introduction*/
		add_submenu_page('reviews-overview', 'Add Reviews', 'Add Reviews', 'manage_options', 'add-reviews', array( &$this, 'AddReviewsPageLayout' ), $icon_url, null);

		add_submenu_page('reviews-overview', 'Edit Reviews', 'Edit Reviews', 'manage_options', 'edit-reviews', array( &$this, 'editReviewsPageLayout' ), $icon_url, null);
		
		add_submenu_page( 'reviews-overview', 'Reviews Settings', 'Reviews Settings', 'manage_options', 'reviews-settings', array( &$this, 'settingsPageLayout' ), $icon_url, null );
		
	} 
	
	protected function addActions() 
	{ 
		/* we want to enable all public and admin 
		scripts and styles */ 
		add_action('wp_enqueue_scripts', array(&$this, 'loadPublicScripts')); 
		add_action('admin_enqueue_scripts', array(&$this, 'loadAdminScripts')); 
		
		/* add menu pages */ 
		add_action('admin_menu', array(&$this, 'addMenuPages')); 
	}
	
	protected function removeActions()
	{
		// actions to be removed.
	}
	
	public function overviewPageLayout()
	{
		$plugin_dir = plugin_dir_path( __FILE__ ) . '../layout/';
		
		ob_start();
		
		include $plugin_dir . 'overview_page.php';
		
		echo ob_get_clean();
	}
	
	public function AddReviewsPageLayout()
	{
		$plugin_dir = plugin_dir_path( __FILE__ ) . '../layout/';
		
		ob_start();
		
		include $plugin_dir . 'add-reviews-page.php';
		
		echo ob_get_clean();
	}
	
	public function editReviewsPageLayout()
	{
		$plugin_dir = plugin_dir_path( __FILE__ ) . '../layout/';
		
		ob_start();
		
		include $plugin_dir . 'edit_reviews.php';
		
		echo ob_get_clean();
	}
	
	public function settingsPageLayout()
	{
		
		$plugin_dir = plugin_dir_path( __FILE__ ) . '../layout/';
		
		ob_start();
		
		include $plugin_dir . 'reviews-settings.php';
		
		echo ob_get_clean();
	}
	
	/* this will preform all functions listed here 
	when the plugin is activated */ 
	public function activate() 
	{ 
		/* this will create our database table to 
		which the forms will be added */ 
		BPReviewsFunctions::createFirstTable();  
		BPReviewsFunctions::createSecondTable();
  
	} 

	/* this will perform all functions listed when 
	the plugin is deactivated */ 
	public function deactivate() 
	{ 
// 		BPReviewsFunctions::destroyFirstTable();
//		BPReviewsFunctions::destroySecondTable();
	}
}